import React from 'react';
import { TextStyle } from 'react-native';
declare type AlertTypes = 'error' | 'warn' | 'info' | 'success';
export interface AlertComponentProps {
    /** Background color will be changed depending on the type. Available values: `error`(red), `success`(green), `warn`(orange) and `info`(blue).
     * @default 'success' */
    alertType: AlertTypes;
    /** While the background of the alert depends on `alertType`, you can also set the other color you want.
     * @default null */
    backgroundColor?: string;
    /** Color of `title` and `description`.
     * @default 'white' */
    textColor?: string;
    /** The maximum number of lines to use for rendering title.
     * @default null */
    maxTitleLines?: number;
    /** The maximum number of lines to use for rendering description.
     * @default null */
    maxDescriptionLines?: number;
    /** A container of the component. Set it in case you use different SafeAreaView than the standard
     * @default SafeAreaView */
    ContainerComponent?: Function;
    /** The style to use for rendering title
     * @default null */
    titleStyle?: TextStyle;
    /** The style to use for rendering description
     * @default null */
    descriptionStyle?: TextStyle;
}
interface AlertComponentAllProps extends AlertComponentProps {
    title?: string;
    description?: string;
}
declare const AlertComponent: React.FunctionComponent<AlertComponentAllProps>;
export default AlertComponent;
